import * as d3 from 'd3';
import { select } from 'd3-selection';

import {
  csv,
  select,
  scaleLinear,
  axisBottom,
  axisLeft,
  schemeCategory10,
} from 'd3';

const csvUrl = 'ICE7.csv'; // Replace with the path to your CSV file

// Define margins and dimensions for the plot
const margin = { top: 20, right: 20, bottom: 50, left: 50 };
const width = 600 - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

// Create SVG container
const svg = select('#scatter-plot-container')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Create scales
const xScale = scaleLinear().range([0, width]);
const yScale = scaleLinear().range([height, 0]);
const colorScale = scaleOrdinal(schemeCategory10);

// Create axes
const xAxis = axisBottom().scale(xScale);
const yAxis = axisLeft().scale(yScale);

// Load data and create scatter plot
csv(csvUrl).then((data) => {
  data.forEach((d) => {
    d.wingspan = +d.wingspan;
    d.beak_length = +d.beak_length;
  });

  // Update scales domain
  xScale.domain([0, d3.max(data, (d) => d.wingspan)]);
  yScale.domain([0, d3.max(data, (d) => d.beak_length)]);

  // Create dots for each data point
  svg
    .selectAll('.dot')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot')
    .attr('cx', (d) => xScale(d.wingspan))
    .attr('cy', (d) => yScale(d.beak_length))
    .attr('r', 5)
    .style('fill', (d, i) => colorScale(i));

  // Append x axis
  svg
    .append('g')
    .attr('class', 'x axis')
    .attr('transform', `translate(0, ${height})`)
    .call(xAxis)
    .append('text')
    .attr('fill', '#000')
    .attr('x', width)
    .attr('y', -6)
    .attr('dy', '0.71em')
    .attr('text-anchor', 'end')
    .text('Wingspan');

  // Append y axis
  svg
    .append('g')
    .attr('class', 'y axis')
    .call(yAxis)
    .append('text')
    .attr('fill', '#000')
    .attr('transform', 'rotate(-90)')
    .attr('y', 6)
    .attr('dy', '0.71em')
    .attr('text-anchor', 'end')
    .text('Beak Length');
});
